| Title: | Download Historical Data from the Belgrade Stock Exchange |
|---|---|
| Description: | Tools for downloading historical financial data from the www.belex.rs. |
| Authors: | Milos Vilotic [aut, cre], Zlatko Kovacic [aut] |
| Maintainer: | Milos Vilotic <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-06-04 09:10:12 UTC |
| Source: | https://github.com/milosvil/belex |
belex function downloads historical financial time series
from the Belgrade Stock Exchange. One can specify which ticker
or index to download, from and to date.
belex(ticker, from = NULL, to = NULL)belex(ticker, from = NULL, to = NULL)
ticker |
a character string giving the name of the ticker or index to download. See the web page of the data provider http://belex.rs for information about the available ticker symbols and indexes. See below. |
from |
date of the start of the period to download. This must be in the following format: yyyy-mm-dd. Defaults to the first available data. |
to |
date of the end of the period to download. This must be in the following format: yyyy-mm-dd. Defaults to the last available data. |
The name of the Belgrade Stock Exchange index is BELEX15 (from September 2005).
A list consists of five components: ticker, from, to,
nrows and data.
Component data is a data frame with the following time series:
Date, Close, Transactions, Volume, Open, Low, High, Total Bid, Total Ask.
Milos Vilotic and Zlatko Kovacic
## Not run: Belex15 index from 2009-11-23 to 2012-05-15 belex15.data <- belex("belex15", "2009-11-23", "2012-05-15") All available data for ticker AIKB aikb.data <- belex("AIKB") Data for ticker NIIS from 2010-10-01 niis.data <- belex("NIIS", from = "2010-10-01") Data for ticker IMLK from beginning to 2010-05-12 imlk.data <- belex("IMLK", to = "2010-05-12") ## End(Not run)## Not run: Belex15 index from 2009-11-23 to 2012-05-15 belex15.data <- belex("belex15", "2009-11-23", "2012-05-15") All available data for ticker AIKB aikb.data <- belex("AIKB") Data for ticker NIIS from 2010-10-01 niis.data <- belex("NIIS", from = "2010-10-01") Data for ticker IMLK from beginning to 2010-05-12 imlk.data <- belex("IMLK", to = "2010-05-12") ## End(Not run)